@@ -151,10 +151,10 @@ class Api(snappi.Api):
         # Sort each port into start, stop, resume, or pause based on current state
         for p in ports:
             if ts['state'] == 'start':
-                if p not in self._transmit_states or self._transmit_states[p] == 'stop':
-                    ports_start.append(p)
-                elif self._transmit_states[p] == 'pause':
+                if p in self._transmit_states and self._transmit_states[p] == 'pause':
                     ports_resume.append(p)
+                else:
+                    ports_start.append(p)
             elif ts['state'] == 'stop':
                 ports_stop.append(p)
             elif ts['state'] == 'pause':
