@@ -74,4 +74,8 @@ class Util:
     def long_to_MAC(value):
         return ':'.join(['{}{}'.format(a,b)
             for a, b in zip(*[iter('{:012x}'.format(value))] * 2)
-        ])
\ No newline at end of file
+        ])
+
+
+    def list_not_empty(key, obj):
+        return key in obj and obj[key] is not None and len(obj[key]) > 0
\ No newline at end of file
